@@ -5,7 +5,7 @@ use warnings;
 
 use MooX::ReturnModifiers qw/return_modifiers/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub import {
     my $target = caller;
@@ -27,7 +27,7 @@ sub construct_attribute {
     my $spec = shift;
     my %attr = ();
     $attr{is} = $spec->[0];
-    $attr{default} = sub { $spec->[1] };
+    $attr{default} = sub { $spec->[1] } if defined $spec->[1];
     map { $attr{$_} = $spec->[2]->{$_} } keys %{ $spec->[2] };
     return %attr;
 }
@@ -39,17 +39,14 @@ __END__
 
 =head1 NAME
 
-MooX::LazierAttributes - Lazier Attributes, well It lets me type 'has', 'is', 'default' less.
+MooX::LazierAttributes - Lazier Attributes.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
-
-
 =head1 SYNOPSIS
 
     package Hello::World;
