@@ -15,7 +15,8 @@ attributes (
     six      => [ 'ro', 0 ],
     seven    => [ 'ro', undef ],
     eight    => [ 'rw' ],
-    nine     => [ 'ro', { broken => 'thing' }, { lazy => 1 } ]
+    nine     => [ 'ro', { broken => 'thing' }, { lazy => 1 } ],
+    ten      => [ 'rw', {}],
 );
 
 
